@@ -34,7 +34,7 @@
 #define PANO13_IMPEX
 #endif
 
-#include "pt_stdint.h"
+#include <stdint.h>
 #include "version.h"
 #include "panotypes.h"
 
@@ -45,6 +45,22 @@
 
 // If you need PT_BIGENDIAN, and don't use MacOS, define it here:
 //#define PT_BIGENDIAN                  1
+#if defined(__GNUC__) && !defined(__MINGW32__)
+#if defined(__FreeBSD__)
+// special check for FreeBSD because it follow its own rules
+#include <sys/endian.h>
+#if defined(_BYTE_ORDER) && (_BYTE_ORDER == _BIG_ENDIAN)
+#define PT_BIGENDIAN 1
+#endif
+#elif defined(__APPLE__)
+#include <machine/endian.h>
+#else
+#include <endian.h>
+#endif
+#if defined(__BYTE_ORDER) && (__BYTE_ORDER == __BIG_ENDIAN)
+#define PT_BIGENDIAN 1
+#endif
+#endif
 
 typedef unsigned char Boolean;
 
